@@ -64,7 +64,7 @@ public:
     Card = 10,
     Game = 11,
     File = 12
-    // if you want to add custom collection types, use a numebr sure to be unique like 101
+    // if you want to add custom collection types, use a number sure to be unique like 101
   };
 
   /**
@@ -283,13 +283,13 @@ public:
    */
   const QStringList& entryGroups() const { return m_entryGroups; }
   /**
-   * Returns a pointer to a const dict of all the entries grouped by
+   * Returns a pointer to a dict of all the entries grouped by
    * a certain field
    *
    * @param name The name of the field by which the entries are grouped
    * @return The list of group names
    */
-  EntryGroupDict* const entryGroupDictByName(const QString& name);
+  EntryGroupDict* entryGroupDictByName(const QString& name);
   /**
    * Invalidates all group names in the collection.
    */
@@ -334,6 +334,8 @@ private:
   void populateDict(EntryGroupDict* dict, const QString& fieldName, EntryVec entries);
   void populateCurrentDicts(EntryVec entries);
   void cleanGroups();
+  bool dependentFieldHasRecursion(FieldPtr field);
+
   /*
    * Gets the preferred ID of the collection. Currently, it just gets incremented as
    * new collections are created.
