@@ -33,9 +33,7 @@ void AddEntries::execute() {
     return;
   }
 
-  for(Data::EntryVecIt entry = m_entries.begin(); entry != m_entries.end(); ++entry) {
-    m_coll->addEntry(entry);
-  }
+  m_coll->addEntries(m_entries);
   Controller::self()->addedEntries(m_entries);
 }
 
@@ -44,9 +42,7 @@ void AddEntries::unexecute() {
     return;
   }
 
-  for(Data::EntryVecIt entry = m_entries.begin(); entry != m_entries.end(); ++entry) {
-    m_coll->removeEntry(entry);
-  }
+  m_coll->removeEntries(m_entries);
   Controller::self()->removedEntries(m_entries);
 }
 
