@@ -21,6 +21,7 @@
 
 #include <qpainter.h>
 #include <qheader.h>
+#include <qdatetime.h>
 #include <qtimer.h>
 
 namespace {
@@ -40,10 +41,6 @@ DetailedEntryItem::~DetailedEntryItem() {
   m_timer = 0;
 }
 
-Tellico::DetailedListView* DetailedEntryItem::listView() const {
-  return static_cast<DetailedListView*>(GUI::ListViewItem::listView());
-}
-
 void DetailedEntryItem::setState(State state_) {
   if(m_state == state_) {
     return;
@@ -123,10 +120,6 @@ QColor DetailedEntryItem::backgroundColor(int column_) {
                      // no more than 20% of highlight color
 }
 
-int DetailedEntryItem::compare(QListViewItem* item_, int col_, bool asc_) const {
-  return listView()->compare(col_, this, item_, asc_);
-}
-
 void DetailedEntryItem::paintFocus(QPainter*, const QColorGroup&, const QRect&) {
 // don't paint anything
 }
