@@ -19,6 +19,9 @@
 #include "tellico_debug.h"
 #include "tellico_utils.h"
 #include "tellico_debug.h"
+#include "latin1literal.h"
+
+#include <klocale.h>
 
 #include <qregexp.h>
 
@@ -46,7 +49,15 @@ bool Entry::operator==(const Entry& e1) {
     QString u = field(QString::fromLatin1("url"));
     if(!u.isEmpty()) {
       // versions before 1.2.7 could have saved the url without the protocol
-      return KURL::fromPathOrURL(u) == KURL::fromPathOrURL(e1.field(QString::fromLatin1("url")));
+      bool b = KURL::fromPathOrURL(u) == KURL::fromPathOrURL(e1.field(QString::fromLatin1("url")));
+      if(b) {
+        return true;
+      } else {
+        Data::FieldPtr f = m_coll->fieldByName(QString::fromLatin1("url"));
+        if(f && f->property(QString::fromLatin1("relative")) == Latin1Literal("true")) {
+          return KURL(Document::self()->URL(), u) == KURL::fromPathOrURL(e1.field(QString::fromLatin1("url")));
+        }
+      }
     }
   }
   if(e1.m_fields.count() != m_fields.count()) {
@@ -148,11 +159,16 @@ QString Entry::formattedField(const QString& fieldName_) const {
   if(!f) {
     return QString::null;
   }
-  if(f->type() == Field::Dependent) {
-    return dependentValue(this, f->description(), true);
-  }
 
   Field::FormatFlag flag = f->formatFlag();
+  if(f->type() == Field::Dependent) {
+    if(flag == Field::FormatNone) {
+      return dependentValue(this, f->description(), false);
+    } else {
+      // format sub fields and whole string
+      return Field::format(dependentValue(this, f->description(), true), flag);
+    }
+  }
 
   // if auto format is not set or FormatNone, then just return the value
   if(flag == Field::FormatNone) {
@@ -176,11 +192,7 @@ QString Entry::formattedField(const QString& fieldName_) const {
 }
 
 QStringList Entry::fields(Data::FieldPtr field_, bool formatted_) const {
-  QString s = formatted_ ? formattedField(field_) : field(field_);
-  if(s.isEmpty()) {
-    return QStringList();
-  }
-  return QStringList::split(QString::fromLatin1("; "), s, true);
+  return fields(field_->name(), formatted_);
 }
 
 QStringList Entry::fields(const QString& field_, bool formatted_) const {
@@ -188,7 +200,7 @@ QStringList Entry::fields(const QString& field_, bool formatted_) const {
   if(s.isEmpty()) {
     return QStringList();
   }
-  return QStringList::split(QString::fromLatin1("; "), s, true);
+  return Field::split(s, true);
 }
 
 bool Entry::setField(Data::FieldPtr field_, const QString& value_) {
@@ -280,7 +292,7 @@ QStringList Entry::groupNamesByFieldName(const QString& fieldName_) const {
   if(!(f->flags() & Field::AllowMultiple)) {
     QString value = formattedField(fieldName_);
     if(value.isEmpty()) {
-      return Collection::s_emptyGroupTitle;
+      return i18n(Collection::s_emptyGroupTitle);
     } else {
       return value;
     }
@@ -288,7 +300,7 @@ QStringList Entry::groupNamesByFieldName(const QString& fieldName_) const {
 
   QStringList groups = fields(fieldName_, true);
   if(groups.isEmpty()) {
-    return Collection::s_emptyGroupTitle;
+    return i18n(Collection::s_emptyGroupTitle);
   } else if(f->type() == Field::Table) {
       // quick hack for tables, how often will a user have "::" in their value?
       // only use first column for group
@@ -319,13 +331,13 @@ void Entry::invalidateFormattedFieldValue(const QString& name_) {
 }
 
 // format is something like "%{year} %{author}"
-QString Entry::dependentValue(ConstEntryPtr entry_, const QString& format_, bool autoCapitalize_) {
+QString Entry::dependentValue(ConstEntryPtr entry_, const QString& format_, bool formatted_) {
   if(!entry_) {
     return format_;
   }
 
   QString result, fieldName;
-  FieldPtr f;
+  FieldPtr field;
 
   int endPos;
   int curPos = 0;
@@ -336,14 +348,14 @@ QString Entry::dependentValue(ConstEntryPtr entry_, const QString& format_, bool
       if(endPos > -1) {
         result += format_.mid(curPos, pctPos-curPos);
         fieldName = format_.mid(pctPos+2, endPos-pctPos-2);
-        f = entry_->collection()->fieldByName(fieldName);
-        if(!f) {
+        field = entry_->collection()->fieldByName(fieldName);
+        if(!field) {
           // allow the user to also use field titles
-          f = entry_->collection()->fieldByTitle(fieldName);
+          field = entry_->collection()->fieldByTitle(fieldName);
         }
-        if(f) {
+        if(field) {
           // don't format, just capitalize
-          result += (autoCapitalize_ ? Field::capitalize(entry_->field(f->name())) : entry_->field(f->name()));
+          result += entry_->field(field, formatted_);
         } else {
           result += format_.mid(pctPos, endPos-pctPos+1);
         }
@@ -390,7 +402,7 @@ int Entry::compareValues(EntryPtr e1, EntryPtr e2, FieldPtr f) {
       return 5;
     }
   }
-  // try removing puctuation
+  // try removing punctuation
   QRegExp notAlphaNum(QString::fromLatin1("[^\\s\\w]"));
   QString s1a = s1; s1a.remove(notAlphaNum);
   QString s2a = s2; s2a.remove(notAlphaNum);
@@ -404,12 +416,13 @@ int Entry::compareValues(EntryPtr e1, EntryPtr e2, FieldPtr f) {
 //    myDebug() << "match without articles" << endl;
     return 3;
   }
+  // try removing everything between parentheses
   QRegExp rx(QString::fromLatin1("\\s*\\(.*\\)\\s*"));
   s1.remove(rx);
   s2.remove(rx);
   if(!s1.isEmpty() && s1 == s2) {
 //    myDebug() << "match without parentheses" << endl;
-    return 1;
+    return 2;
   }
   if(f->flags() & Field::AllowMultiple) {
     QStringList sl1 = e1->fields(f, false);
