@@ -29,11 +29,14 @@ class QLabel;
 #include "../datavectors.h"
 
 #include <kurl.h>
-#include <kio/job.h>
 
 #include <qcstring.h> // for QByteArray
 #include <qguardedptr.h>
 
+namespace KIO {
+  class Job;
+}
+
 namespace Tellico {
   namespace Fetch {
 
