@@ -279,7 +279,7 @@ void SRUFetcher::slotComplete(KIO::Job* job_) {
       default:
         break;
     }
-    SearchResult* r = new SearchResult(this, entry->title(), desc);
+    SearchResult* r = new SearchResult(this, entry->title(), desc, entry->field(QString::fromLatin1("isbn")));
     m_entries.insert(r->uid, entry);
     emit signalResultFound(r);
   }
