@@ -110,7 +110,7 @@ private:
   QString m_value;
   QMap<int, Data::EntryPtr> m_entries;
   bool m_started;
-  QStringList m_isbnList;
+  bool m_done;
   QString m_preset;
 
   XSLTHandler* m_MARC21XMLHandler;
