@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -17,6 +17,7 @@
 #include "tellico_strings.h"
 #include "tellico_utils.h"
 #include "tellico_debug.h"
+#include "core/netaccess.h"
 
 #include <kurl.h>
 #include <klocale.h>
@@ -25,22 +26,43 @@
 #include <ktempfile.h>
 #include <ksavefile.h>
 #include <kapplication.h>
+#include <kfileitem.h>
+#include <kio/chmodjob.h>
 
 #include <qdom.h>
 #include <qfile.h>
 
 using Tellico::FileHandler;
 
+class FileHandler::ItemDeleter : public QObject {
+public:
+  ItemDeleter(KIO::Job* job, KFileItem* item) : QObject(), m_job(job), m_item(item) {
+    FileHandler::s_deleterList.append(this);
+    connect(job, SIGNAL(result(KIO::Job*)), SLOT(deleteLater()));
+  }
+  ~ItemDeleter() {
+    FileHandler::s_deleterList.removeRef(this);
+    if(m_job) m_job->kill();
+    delete m_item; m_item = 0;
+  }
+private:
+  QGuardedPtr<KIO::Job> m_job;
+  KFileItem* m_item;
+};
+
+QPtrList<FileHandler::ItemDeleter> FileHandler::s_deleterList;
+
 FileHandler::FileRef::FileRef(const KURL& url_, bool quiet_) : m_file(0), m_isValid(false) {
   if(url_.isEmpty()) {
     return;
   }
 
-#if KDE_IS_VERSION(3,1,90)
-  if(!KIO::NetAccess::download(url_, m_filename, Kernel::self()->widget())) {
-#else
-  if(!KIO::NetAccess::download(url_, m_filename)) {
-#endif
+  if(!Tellico::NetAccess::download(url_, m_filename, Kernel::self()->widget())) {
+    myDebug() << "FileRef::FileRef() - can't download " << url_ << endl;
+    QString s = KIO::NetAccess::lastErrorString();
+    if(!s.isEmpty()) {
+      myDebug() << s << endl;
+    }
     if(!quiet_) {
       Kernel::self()->sorry(i18n(errorLoad).arg(url_.fileName()));
     }
@@ -58,7 +80,7 @@ FileHandler::FileRef::FileRef(const KURL& url_, bool quiet_) : m_file(0), m_isVa
 
 FileHandler::FileRef::~FileRef() {
   if(!m_filename.isEmpty()) {
-    KIO::NetAccess::removeTempFile(m_filename);
+    Tellico::NetAccess::removeTempFile(m_filename);
   }
   if(m_file) {
     m_file->close();
@@ -80,7 +102,6 @@ bool FileHandler::FileRef::open(bool quiet_) {
     }
     delete m_file;
     m_file = 0;
-    KIO::NetAccess::removeTempFile(m_filename);
     m_isValid = false;
     return false;
   }
@@ -91,7 +112,7 @@ FileHandler::FileRef* FileHandler::fileRef(const KURL& url_, bool quiet_) {
   return new FileRef(url_, quiet_);
 }
 
-QString FileHandler::readTextFile(const KURL& url_, bool quiet_) {
+QString FileHandler::readTextFile(const KURL& url_, bool quiet_/*=false*/) {
   FileRef f(url_, quiet_);
   if(!f.isValid()) {
     return QString::null;
@@ -136,6 +157,28 @@ QByteArray FileHandler::readDataFile(const KURL& url_, bool quiet_) {
   return f.file()->readAll();
 }
 
+Tellico::Data::Image* FileHandler::readImageFile(const KURL& url_, bool quiet_, const KURL& referrer_) {
+  if(url_.isLocalFile()) {
+    return readImageFile(url_, quiet_);
+  }
+
+  KTempFile tmpFile;
+  KURL tmpURL;
+  tmpURL.setPath(tmpFile.name());
+  tmpFile.setAutoDelete(true);
+
+  KIO::Job* job = KIO::file_copy(url_, tmpURL, -1, true /* overwrite */);
+  job->addMetaData(QString::fromLatin1("referrer"), referrer_.url());
+
+  if(!KIO::NetAccess::synchronousRun(job, Kernel::self()->widget())) {
+    if(!quiet_) {
+      Kernel::self()->sorry(i18n(errorLoad).arg(url_.fileName()));
+    }
+    return 0;
+  }
+  return readImageFile(tmpURL, quiet_);
+}
+
 Tellico::Data::Image* FileHandler::readImageFile(const KURL& url_, bool quiet_) {
   FileRef f(url_, quiet_);
   if(!f.isValid()) {
@@ -151,53 +194,95 @@ Tellico::Data::Image* FileHandler::readImageFile(const KURL& url_, bool quiet_)
 }
 
 bool FileHandler::queryExists(const KURL& url_) {
+  if(url_.isEmpty() || !KIO::NetAccess::exists(url_, false, Kernel::self()->widget())) {
+    return true;
+  }
+
+  // we always overwrite the current URL without asking
+  if(url_ != Kernel::self()->URL()) {
+    GUI::CursorSaver cs(Qt::arrowCursor);
+    QString str = i18n("A file named \"%1\" already exists. "
+                       "Are you sure you want to overwrite it?").arg(url_.fileName());
+    int want_continue = KMessageBox::warningContinueCancel(Kernel::self()->widget(), str,
+                                                           i18n("Overwrite File?"),
+                                                           i18n("Overwrite"));
+
+    if(want_continue == KMessageBox::Cancel) {
+      return false;
+    }
+  }
+
+  KURL backup(url_);
+  backup.setPath(backup.path() + QString::fromLatin1("~"));
+
   bool success = true;
-#if KDE_IS_VERSION(3,1,90)
-  if(KIO::NetAccess::exists(url_, false, Kernel::self()->widget())) {
-#else
-  if(KIO::NetAccess::exists(url_, false)) {
-#endif
-    if(url_ != Kernel::self()->URL()) {
-      GUI::CursorSaver cs(Qt::arrowCursor);
-      QString str = i18n("A file named \"%1\" already exists. "
-                         "Are you sure you want to overwrite it?").arg(url_.fileName());
-      int want_continue = KMessageBox::warningContinueCancel(Kernel::self()->widget(), str,
-                                                             i18n("Overwrite File?"),
-                                                             i18n("Overwrite"));
+  if(url_.isLocalFile()) {
+    // KSaveFile messes up users and groups
+    // the user is always reset to the current user
+    KFileItemList list;
+    int perm = -1;
+    QString grp;
+    if(KIO::NetAccess::exists(url_, false, Kernel::self()->widget())) {
+      KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url_, true);
+      perm = item.permissions();
+      grp = item.group();
 
-      if(want_continue == KMessageBox::Cancel) {
-        return false;
-      }
+      KFileItem* backupItem = new KFileItem(KFileItem::Unknown, KFileItem::Unknown, backup, true);
+      list.append(backupItem);
     }
 
-    KURL backup(url_);
-    backup.setPath(backup.path() + QString::fromLatin1("~"));
-#if KDE_IS_VERSION(3,1,90)
+    success = KSaveFile::backupFile(url_.path());
+    if(!list.isEmpty()) {
+      // have to leave the user alone
+      KIO::Job* job = KIO::chmod(list, perm, 0, QString(), grp, true, false);
+      new ItemDeleter(job, list.first());
+    }
+  } else {
     KIO::NetAccess::del(backup, Kernel::self()->widget()); // might fail if backup doesn't exist, that's ok
-    success = KIO::NetAccess::copy(url_, backup, Kernel::self()->widget());
-#else
-    KIO::NetAccess::del(backup); // might fail if backup doesn't exist, that's ok
-    success = KIO::NetAccess::copy(url_, backup);
-#endif
-    if(!success) {
-      Kernel::self()->sorry(i18n(errorWrite).arg(backup.fileName()));
-    }
+    success = KIO::NetAccess::file_copy(url_, backup, -1 /* permissions */, true /* overwrite */,
+                                        false /* resume */, Kernel::self()->widget());
+  }
+  if(!success) {
+    Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName() + '~'));
   }
   return success;
 }
 
-bool FileHandler::writeTextURL(const KURL& url_, const QString& text_, bool encodeUTF8_, bool force_) {
+bool FileHandler::writeTextURL(const KURL& url_, const QString& text_, bool encodeUTF8_, bool force_, bool quiet_) {
   if((!force_ && !queryExists(url_)) || text_.isNull()) {
+    if(text_.isNull()) {
+      myDebug() << "FileHandler::writeTextURL() - null string for " << url_ << endl;
+    }
     return false;
   }
 
   if(url_.isLocalFile()) {
+    // KSaveFile messes up users and groups
+    // the user is always reset to the current user
+    KFileItemList list;
+    int perm = -1;
+    QString grp;
+    if(KIO::NetAccess::exists(url_, false, Kernel::self()->widget())) {
+      KFileItem* item = new KFileItem(KFileItem::Unknown, KFileItem::Unknown, url_, true);
+      list.append(item);
+      perm = item->permissions();
+      grp = item->group();
+    }
+
     KSaveFile f(url_.path());
     if(f.status() != 0) {
-      Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+      if(!quiet_) {
+        Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+      }
       return false;
     }
-    return FileHandler::writeTextFile(f, text_, encodeUTF8_);
+    bool success = FileHandler::writeTextFile(f, text_, encodeUTF8_);
+    if(!list.isEmpty()) {
+      // have to leave the user alone
+      KIO::Job* job = KIO::chmod(list, perm, 0, QString(), grp, true, false);
+      new ItemDeleter(job, list.first());
+    }
+    return success;
   }
 
   // save to remote file
@@ -205,20 +290,20 @@ bool FileHandler::writeTextURL(const KURL& url_, const QString& text_, bool enco
   KSaveFile f(tempfile.name());
   if(f.status() != 0) {
     tempfile.unlink();
-    Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+    if(!quiet_) {
+      Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+    }
     return false;
   }
 
   bool success = FileHandler::writeTextFile(f, text_, encodeUTF8_);
   if(success) {
-#if KDE_IS_VERSION(3,1,90)
     bool uploaded = KIO::NetAccess::upload(tempfile.name(), url_, Kernel::self()->widget());
-#else
-    bool uploaded = KIO::NetAccess::upload(tempfile.name(), url_);
-#endif
     if(!uploaded) {
       tempfile.unlink();
-      Kernel::self()->sorry(i18n(errorUpload).arg(url_.fileName()));
+      if(!quiet_) {
+        Kernel::self()->sorry(i18n(errorUpload).arg(url_.fileName()));
+      }
       success = false;
     }
   }
@@ -241,44 +326,61 @@ bool FileHandler::writeTextFile(KSaveFile& f_, const QString& text_, bool encode
   bool success = f_.close();
 #ifndef NDEBUG
   if(!success) {
-    kdDebug() << "FileHandler::writeTextFile() - status = " << f_.status();
+    myDebug() << "FileHandler::writeTextFile() - status = " << f_.status();
   }
 #endif
   return success;
 }
 
-bool FileHandler::writeDataURL(const KURL& url_, const QByteArray& data_, bool force_) {
+bool FileHandler::writeDataURL(const KURL& url_, const QByteArray& data_, bool force_, bool quiet_) {
   if(!force_ && !queryExists(url_)) {
     return false;
   }
 
   if(url_.isLocalFile()) {
+    // KSaveFile messes up users and groups
+    // the user is always reset to the current user
+    KFileItemList list;
+    int perm = -1;
+    QString grp;
+    if(KIO::NetAccess::exists(url_, false, Kernel::self()->widget())) {
+      KFileItem* item = new KFileItem(KFileItem::Unknown, KFileItem::Unknown, url_, true);
+      list.append(item);
+      perm = item->permissions();
+      grp = item->group();
+    }
+
     KSaveFile f(url_.path());
     if(f.status() != 0) {
-      Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+      if(!quiet_) {
+        Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+      }
       return false;
     }
-    return FileHandler::writeDataFile(f, data_);
+    bool success = FileHandler::writeDataFile(f, data_);
+    if(!list.isEmpty()) {
+      // have to leave the user alone
+      KIO::Job* job = KIO::chmod(list, perm, 0, QString(), grp, true, false);
+      new ItemDeleter(job, list.first());
+    }
+    return success;
   }
 
   // save to remote file
   KTempFile tempfile;
   KSaveFile f(tempfile.name());
   if(f.status() != 0) {
-    Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+    if(!quiet_) {
+      Kernel::self()->sorry(i18n(errorWrite).arg(url_.fileName()));
+    }
     return false;
   }
 
   bool success = FileHandler::writeDataFile(f, data_);
   if(success) {
-#if KDE_IS_VERSION(3,1,90)
-    bool uploaded = KIO::NetAccess::upload(tempfile.name(), url_, Kernel::self()->widget());
-#else
-    bool uploaded = KIO::NetAccess::upload(tempfile.name(), url_);
-#endif
-    if(!uploaded) {
+    success = KIO::NetAccess::upload(tempfile.name(), url_, Kernel::self()->widget());
+    if(!success && !quiet_) {
       Kernel::self()->sorry(i18n(errorUpload).arg(url_.fileName()));
-      success = false;
     }
   }
   tempfile.unlink();
@@ -287,8 +389,14 @@ bool FileHandler::writeDataURL(const KURL& url_, const QByteArray& data_, bool f
 }
 
 bool FileHandler::writeDataFile(KSaveFile& f_, const QByteArray& data_) {
-//  kdDebug() << "FileHandler::writeDataFile()" << endl;
+//  myDebug() << "FileHandler::writeDataFile()" << endl;
   QDataStream* s = f_.dataStream();
   s->writeRawBytes(data_.data(), data_.size());
   return f_.close();
 }
+
+void FileHandler::clean() {
+  s_deleterList.setAutoDelete(true);
+  s_deleterList.clear();
+  s_deleterList.setAutoDelete(false);
+}
