@@ -58,6 +58,7 @@
 #include <unistd.h>
 
 #include <kapplication.h>
+#include <kcombobox.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
 #include <kmenubar.h>
@@ -388,8 +389,8 @@ void MainWindow::initActions() {
 #endif
 
   action = new KAction(actionCollection(), "file_import_gcfilms");
-  action->setText(i18n("Import GCfilms Data..."));
-  action->setToolTip(i18n("Import a GCfilms data file"));
+  action->setText(i18n("Import GCstar Data..."));
+  action->setToolTip(i18n("Import a GCstar data file"));
   importMenu->insert(action);
   connect(action, SIGNAL(activated()), importMapper, SLOT(map()));
   importMapper->setMapping(action, Import::GCfilms);
@@ -1080,7 +1081,6 @@ void MainWindow::slotFileOpen(const KURL& url_) {
     if(openURL(url_)) {
       m_fileOpenRecent->addURL(url_);
       m_fileOpenRecent->setCurrentItem(-1);
-      ImageFactory::clean(false);
     }
   }
 
@@ -1744,22 +1744,26 @@ void MainWindow::slotUpdateFilter() {
 
   QString text = m_quickFilter->text().stripWhiteSpace();
   if(!text.isEmpty()) {
-    filter = new Filter(Filter::MatchAny);
-    // if the text contains any non-Word characters, assume it's a regexp
-    QRegExp rx(QString::fromLatin1("\\W"));
-    FilterRule* rule;
+    filter = new Filter(Filter::MatchAll);
+    // if the text contains any non-word characters, assume it's a regexp
+    // but \W in qt is letter, number, or '_', I want to be a bit less strict
+    QRegExp rx(QString::fromLatin1("[^\\w\\s-']"));
     if(text.find(rx) == -1) {
-      // an empty field string means check every field
-      rule = new FilterRule(QString::null, text, FilterRule::FuncContains);
+      // split by whitespace, and add rules for each word
+      QStringList tokens = QStringList::split(QRegExp(QString::fromLatin1("\\s")), text);
+      for(QStringList::Iterator it = tokens.begin(); it != tokens.end(); ++it) {
+        // an empty field string means check every field
+        filter->append(new FilterRule(QString::null, *it, FilterRule::FuncContains));
+      }
     } else {
       // if it isn't valid, hold off on applying the filter
       QRegExp tx(text);
       if(!tx.isValid()) {
+        myDebug() << "MainWindow::slotUpdateFilter() - invalid regexp: " << text << endl;
         return;
       }
-      rule = new FilterRule(QString::null, text, FilterRule::FuncRegExp);
+      filter->append(new FilterRule(QString::null, text, FilterRule::FuncRegExp));
     }
-    filter->append(rule);
   }
   // only update filter if one exists or did exist
   if(filter || m_detailedView->filter()) {
@@ -1811,8 +1815,7 @@ void MainWindow::slotFileImport(int format_) {
   }
 
   if(checkURL) {
-    bool ok = !url.isEmpty() && url.isValid();
-    ok &= KIO::NetAccess::exists(url, true, this);
+    bool ok = !url.isEmpty() && url.isValid() && KIO::NetAccess::exists(url, true, this);
     if(!ok) {
       StatusBar::self()->clearStatus();
       return;
@@ -2012,8 +2015,8 @@ void MainWindow::slotCiteEntry(int action_) {
 void MainWindow::slotShowFetchDialog() {
   if(!m_fetchDlg) {
     m_fetchDlg = new FetchDialog(this);
-    connect(m_fetchDlg, SIGNAL(finished()),
-            SLOT(slotHideFetchDialog()));
+    connect(m_fetchDlg, SIGNAL(finished()), SLOT(slotHideFetchDialog()));
+    connect(Controller::self(), SIGNAL(collectionAdded(int)), m_fetchDlg, SLOT(slotResetCollection()));
   } else {
     KWin::activateWindow(m_fetchDlg->winId());
   }
@@ -2279,6 +2282,7 @@ void MainWindow::updateCollectionActions() {
     default:
       break;
   }
+  Controller::self()->updateActions();
   // special case when there are no available data sources
   if(m_fetchActions.isEmpty() && m_updateAll) {
     m_updateAll->setEnabled(false);
