@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -65,7 +65,7 @@ public:
    *
    * @return the field titles
    */
-  const QStringList& Kernel::fieldTitles() const;
+  const QStringList& fieldTitles() const;
   /**
    * Returns the name of an field, given its title. Wraps the call to the collection itself.
    *
@@ -82,8 +82,8 @@ public:
   QString fieldTitleByName(const QString& name) const;
   QStringList valuesByFieldName(const QString& name) const;
 
-  const QString& entryName() const;
   int collectionType() const;
+  QString collectionTypeName() const;
 
   void sorry(const QString& text, QWidget* widget=0);
 
@@ -91,26 +91,34 @@ public:
   void endCommandGroup();
   void resetHistory();
 
-  bool addField(Data::Field* field);
-  bool modifyField(Data::Field* field);
-  bool removeField(Data::Field* field);
+  bool addField(Data::FieldPtr field);
+  bool modifyField(Data::FieldPtr field);
+  bool removeField(Data::FieldPtr field);
 
-  void saveEntries(Data::EntryVec oldEntries, Data::EntryVec entries);
+  void addEntries(Data::EntryVec entries, bool checkFields);
+  void modifyEntries(Data::EntryVec oldEntries, Data::EntryVec newEntries);
+  void updateEntry(Data::EntryPtr oldEntry, Data::EntryPtr newEntry, bool overWrite);
   void removeEntries(Data::EntryVec entries);
 
   bool addLoans(Data::EntryVec entries);
-  bool modifyLoan(Data::Loan* loan);
+  bool modifyLoan(Data::LoanPtr loan);
   bool removeLoans(Data::LoanVec loans);
 
-  void addFilter(Filter* filter);
-  bool modifyFilter(Filter* filter);
-  bool removeFilter(Filter* filter);
+  void addFilter(FilterPtr filter);
+  bool modifyFilter(FilterPtr filter);
+  bool removeFilter(FilterPtr filter);
 
   void reorderFields(const Data::FieldVec& fields);
 
-  void appendCollection(Data::Collection* coll);
-  void mergeCollection(Data::Collection* coll);
-  void replaceCollection(Data::Collection* coll);
+  void appendCollection(Data::CollPtr coll);
+  void mergeCollection(Data::CollPtr coll);
+  void replaceCollection(Data::CollPtr coll);
+
+  // adds new fields into collection if any values in entries are not empty
+  // first object is modified fields, second is new fields
+  QPair<Data::FieldVec, Data::FieldVec> mergeFields(Data::CollPtr coll,
+                                                    Data::FieldVec fields,
+                                                    Data::EntryVec entries);
 
   void renameCollection();
   const KCommandHistory* commandHistory() { return &m_commandHistory; }
