@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -15,33 +15,39 @@
 #define HTMLEXPORTER_H
 
 class QCheckBox;
-class KHTMLPart;
-namespace DOM {
-  class Node;
-}
 
 #include "exporter.h"
 #include "../stringset.h"
 
 #include <qstringlist.h>
 
+#include <libxml/xmlstring.h>
+
+extern "C" {
+  struct _xmlNode;
+}
+
 namespace Tellico {
   namespace Data {
     class Collection;
   }
   class XSLTHandler;
+
   namespace Export {
 
 /**
  * @author Robby Stephenson
  */
 class HTMLExporter : public Exporter {
+Q_OBJECT
+
 public:
   HTMLExporter();
-  HTMLExporter(const Data::Collection* coll);
+  HTMLExporter(Data::CollPtr coll);
   ~HTMLExporter();
 
   virtual bool exec();
+  virtual void reset();
   virtual QString formatString() const;
   virtual QString fileFilter() const;
 
@@ -58,26 +64,36 @@ public:
   void setSortTitles(const QStringList& l)
     { m_sort1 = l[0]; m_sort2 = l[1]; m_sort3 = l[2]; }
   void setColumns(const QStringList& columns) { m_columns = columns; }
+  void setParseDOM(bool parseDOM) { m_parseDOM = parseDOM; reset(); }
 
   QString text();
 
+public slots:
+  void slotCancel();
+
 private:
-  void setFormattingOptions(const Data::Collection* coll);
-  void writeImages(const Data::Collection* coll);
+  void setFormattingOptions(Data::CollPtr coll);
+  void writeImages(Data::CollPtr coll);
   bool writeEntryFiles();
   KURL fileDir() const;
   QString fileDirName() const;
 
-  void parseNode(DOM::Node node);
+  void parseDOM(_xmlNode* node);
   QString handleLink(const QString& link);
+  const xmlChar* handleLink(const xmlChar* link);
   QString analyzeInternalCSS(const QString& string);
+  const xmlChar* analyzeInternalCSS(const xmlChar* string);
   bool copyFiles();
+  bool loadXSLTFile();
+  void createDir();
 
-  KHTMLPart* m_part;
   XSLTHandler* m_handler;
-  bool m_printHeaders;
-  bool m_printGrouped;
-  bool m_exportEntryFiles;
+  bool m_printHeaders : 1;
+  bool m_printGrouped : 1;
+  bool m_exportEntryFiles : 1;
+  bool m_cancelled : 1;
+  bool m_parseDOM : 1;
+  bool m_checkCreateDir : 1;
   int m_imageWidth;
   int m_imageHeight;
 
@@ -90,6 +106,7 @@ private:
   KURL m_collectionURL;
   QString m_xsltFile;
   QString m_xsltFilePath;
+  QString m_dataDir;
   QStringList m_groupBy;
   QString m_sort1;
   QString m_sort2;
