@@ -18,6 +18,7 @@
 #include "../entry.h"
 #include "../field.h"
 #include "../imagefactory.h"
+#include "../image.h"
 #include "../isbnvalidator.h"
 #include "../latin1literal.h"
 #include "../tellico_strings.h"
@@ -31,6 +32,7 @@
 #include <kzip.h>
 #include <kapplication.h>
 
+#include <qdom.h>
 #include <qbuffer.h>
 #include <qfile.h>
 #include <qtimer.h>
@@ -163,10 +165,12 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
 
   // the collection item should be the first dom element child of the root
   QDomElement collelem;
-  QDomNodeList childs = root.childNodes();
-  for(uint i = 0; i < childs.length(); ++i) {
-    if(childs.item(i).isElement() && childs.item(i).localName() == Latin1Literal("collection")) {
-      collelem = childs.item(i).toElement();
+  for(QDomNode n = root.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    if(n.namespaceURI() != m_namespace) {
+      continue;
+    }
+    if(n.isElement() && n.localName() == Latin1Literal("collection")) {
+      collelem = n.toElement();
       break;
     }
   }
@@ -183,9 +187,12 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
   // for fields, each true field element is a child of a fields element
   QDomNodeList fieldelems;
   for(QDomNode n = collelem.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    if(n.namespaceURI() != m_namespace) {
+      continue;
+    }
     // Latin1Literal is a macro, so can't say Latin1Literal(syntaxVersion > 3 ? "fields" : "attributes")
-    if((syntaxVersion > 3 && n.nodeName() == Latin1Literal("fields"))
-       || (syntaxVersion < 4 && n.nodeName() == Latin1Literal("attributes"))) {
+    if((syntaxVersion > 3 && n.localName() == Latin1Literal("fields"))
+       || (syntaxVersion < 4 && n.localName() == Latin1Literal("attributes"))) {
       QDomElement e = n.toElement();
       fieldelems = e.elementsByTagNameNS(m_namespace, (syntaxVersion > 3) ? QString::fromLatin1("field")
                                                                           : QString::fromLatin1("attribute"));
@@ -233,7 +240,10 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
     Data::BibtexCollection* c = static_cast<Data::BibtexCollection*>(m_coll.data());
     QDomNodeList macroelems;
     for(QDomNode n = collelem.firstChild(); !n.isNull(); n = n.nextSibling()) {
-      if(n.nodeName() == Latin1Literal("macros")) {
+      if(n.namespaceURI() != m_namespace) {
+        continue;
+      }
+      if(n.localName() == Latin1Literal("macros")) {
         macroelems = n.toElement().elementsByTagNameNS(m_namespace, QString::fromLatin1("macro"));
         break;
       }
@@ -245,7 +255,10 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
     }
 
     for(QDomNode n = collelem.firstChild(); !n.isNull(); n = n.nextSibling()) {
-      if(n.nodeName() == Latin1Literal("bibtex-preamble")) {
+      if(n.namespaceURI() != m_namespace) {
+        continue;
+      }
+      if(n.localName() == Latin1Literal("bibtex-preamble")) {
         c->setPreamble(n.toElement().text());
         break;
       }
@@ -265,16 +278,20 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
 
   const uint count = collelem.childNodes().count();
   const uint stepSize = QMAX(s_stepSize, count/100);
+  const bool showProgress = options() & ImportProgress;
 
   item.setTotalSteps(count);
 
   uint j = 0;
   for(QDomNode n = collelem.firstChild(); !n.isNull() && !m_cancelled; n = n.nextSibling(), ++j) {
-    if(n.nodeName() == entryName) {
+    if(n.namespaceURI() != m_namespace) {
+      continue;
+    }
+    if(n.localName() == entryName) {
       readEntry(syntaxVersion, n.toElement());
 
       // not exactly right, but close enough
-      if(j%stepSize == 0) {
+      if(showProgress && j%stepSize == 0) {
         ProgressManager::self()->setProgress(this, j);
         kapp->processEvents();
       }
@@ -287,27 +304,31 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
   }
 
   // m_loadAllImages only pertains to zip files
-  if(loadImages_) {
-    QDomNodeList imgelems;
-    for(QDomNode n = collelem.firstChild(); !n.isNull(); n = n.nextSibling()) {
-      if(n.nodeName() == Latin1Literal("images")) {
-        imgelems = n.toElement().elementsByTagNameNS(m_namespace, QString::fromLatin1("image"));
-        break;
-      }
+  QDomNodeList imgelems;
+  for(QDomNode n = collelem.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    if(n.namespaceURI() != m_namespace) {
+      continue;
     }
-    for(uint j = 0; j < imgelems.count(); ++j) {
-      readImage(imgelems.item(j).toElement());
+    if(n.localName() == Latin1Literal("images")) {
+      imgelems = n.toElement().elementsByTagNameNS(m_namespace, QString::fromLatin1("image"));
+      break;
     }
   }
+  for(uint j = 0; j < imgelems.count(); ++j) {
+    readImage(imgelems.item(j).toElement(), loadImages_);
+  }
 
   // filters and borrowers are at document root level, not collection
   for(QDomNode n = root.firstChild(); !n.isNull() && !m_cancelled; n = n.nextSibling()) {
-    if(n.nodeName() == Latin1Literal("borrowers")) {
+    if(n.namespaceURI() != m_namespace) {
+      continue;
+    }
+    if(n.localName() == Latin1Literal("borrowers")) {
       QDomNodeList borrowerElems = n.toElement().elementsByTagNameNS(m_namespace, QString::fromLatin1("borrower"));
       for(uint j = 0; j < borrowerElems.count(); ++j) {
         readBorrower(borrowerElems.item(j).toElement());
       }
-    } else if(n.nodeName() == Latin1Literal("filters")) {
+    } else if(n.localName() == Latin1Literal("filters")) {
       QDomNodeList filterElems = n.toElement().elementsByTagNameNS(m_namespace, QString::fromLatin1("filter"));
       for(uint j = 0; j < filterElems.count(); ++j) {
         readFilter(filterElems.item(j).toElement());
@@ -451,11 +472,11 @@ void TellicoImporter::readEntry(uint syntaxVersion_, const QDomElement& entryEle
     // in version 3 and prior, checkbox attributes had no text(), set it to "true" now
     if(syntaxVersion_ < 4 && elem.text().isEmpty()) {
       // "true" means checked
-      entry->setField(elem.tagName(), QString::fromLatin1("true"));
+      entry->setField(elem.localName(), QString::fromLatin1("true"));
       continue;
     }
 
-    QString name = elem.tagName();
+    QString name = elem.localName();
     Data::FieldPtr f = m_coll->fieldByName(name);
 
     // if the first child of the node is a text node, just set the attribute text
@@ -500,6 +521,18 @@ void TellicoImporter::readEntry(uint syntaxVersion_, const QDomElement& entryEle
       if(value.isEmpty()) {
         continue;
       }
+
+      if(f->type() == Data::Field::Image) {
+        // for local files only, allow paths here
+        KURL u = KURL::fromPathOrURL(value);
+        if(u.isValid() && u.isLocalFile()) {
+          QString result = ImageFactory::addImage(u, false /* quiet */);
+          if(!result.isEmpty()) {
+            value = result;
+          }
+        }
+      }
+
       // in version 8, old rating fields get changed
       if(syntaxVersion_ < 8 && f->type() == Data::Field::Rating) {
         bool ok;
@@ -585,15 +618,27 @@ void TellicoImporter::readEntry(uint syntaxVersion_, const QDomElement& entryEle
   m_coll->addEntries(entry);
 }
 
-void TellicoImporter::readImage(const QDomElement& elem_) {
+void TellicoImporter::readImage(const QDomElement& elem_, bool loadImage_) {
   QString format = elem_.attribute(QString::fromLatin1("format"));
-  QString id = elem_.attribute(QString::fromLatin1("id"));
+  QString id = shareString(elem_.attribute(QString::fromLatin1("id")));
 
-  QByteArray ba;
-  KCodecs::base64Decode(QCString(elem_.text().latin1()), ba);
-  if(!ba.isEmpty()) {
-    ImageFactory::addImage(ba, format, id);
-    m_hasImages = true;
+  if(loadImage_) {
+    QByteArray ba;
+    KCodecs::base64Decode(QCString(elem_.text().latin1()), ba);
+    if(!ba.isEmpty()) {
+      QString result = ImageFactory::addImage(ba, format, id);
+      if(result.isEmpty()) {
+        myDebug() << "TellicoImporter::readImage(XML) - null image for " << id << endl;
+      }
+      m_hasImages = true;
+    }
+  } else {
+    int width = elem_.attribute(QString::fromLatin1("width")).toInt();
+    int height = elem_.attribute(QString::fromLatin1("height")).toInt();
+    if(width > 0 && height > 0) {
+      Data::ImageInfo info(id, format.latin1(), width, height);
+      ImageFactory::cacheImageInfo(info);
+    }
   }
 }
 
@@ -780,6 +825,7 @@ void TellicoImporter::loadZipData() {
 
   const QStringList images = static_cast<const KArchiveDirectory*>(imgDirEntry)->entries();
   const uint stepSize = QMAX(s_stepSize, images.count()/100);
+
   uint j = 0;
   for(QStringList::ConstIterator it = images.begin(); !m_cancelled && it != images.end(); ++it, ++j) {
     const KArchiveEntry* file = m_imgDir->entry(*it);
