@@ -16,8 +16,11 @@
 #include "../tellico_debug.h"
 #include "../tellico_utils.h"
 
+#include <qdom.h>
 #include <qtextcodec.h>
 
+#include <kurl.h>
+
 extern "C" {
 #include <libxslt/xslt.h>
 #include <libxslt/transform.h>
